@@ -27,20 +27,21 @@ DEALINGS IN THE SOFTWARE.
 """
 
 import abc
+import json
 import sys
 import copy
 import asyncio
 
 from .iterators import HistoryIterator
 from .context_managers import Typing
-from .enums import ChannelType
+from .enums import try_enum, ChannelType, PermissionType
 from .errors import InvalidArgument, ClientException
 from .mentions import AllowedMentions
 from .permissions import PermissionOverwrite, Permissions
 from .role import Role
 from .invite import Invite
 from .file import File
-from .components import Button, DropdownMenue, ActionRow
+from .components import Button, SelectMenu, ActionRow
 from .voice_client import VoiceClient, VoiceProtocol
 from . import utils
 
@@ -327,10 +328,13 @@ class GuildChannel:
         everyone_id = self.guild.id
 
         for index, overridden in enumerate(data.get('permission_overwrites', [])):
+            overridden_type = try_enum(PermissionType, overridden.pop('type'))
+            if not overridden_type:
+                raise AttributeError('Type type should be 0 - member, or 1 - role not %s' % overridden_type)
             overridden_id = int(overridden.pop('id'))
-            self._overwrites.append(_Overwrites(id=overridden_id, **overridden))
+            self._overwrites.append(_Overwrites(id=overridden_id, type=overridden_type.name, **overridden))
 
-            if overridden['type'] == 'member':
+            if overridden_type.name == 'member':
                 continue
 
             if overridden_id == everyone_id:
@@ -933,10 +937,10 @@ class Messageable(metaclass=abc.ABCMeta):
     async def _get_channel(self):
         raise NotImplementedError
 
-    async def send(self, content=None, *, tts=False, embed=None, components=None, file=None,
+    async def send(self, content=None, *, tts=False, embed=None, embeds=None, components=None, file=None,
                                           files=None, delete_after=None, nonce=None,
                                           allowed_mentions=None, reference=None,
-                                          mention_author=None):
+                                          mention_author=None, hidden=None, **kwargs):
         """|coro|
 
         Sends a message to the destination with the content given.
@@ -961,8 +965,10 @@ class Messageable(metaclass=abc.ABCMeta):
             Indicates if the message should be sent using text-to-speech.
         embed: :class:`~discord.Embed`
             The rich embed for the content.
-        components: List[:class:`discord.ActionRow`]
-            A list of :type:`discord.Actionrow`'s
+        embeds: List[:class:`~discord.Embed`]
+            A list containing up to ten embeds
+        components: List[Union[:class:`ActionRow`, List[Union[:class:`Button`, :class:`SelectMenu`]]]]
+            A list of :type:`discord.ActionRow`'s or a list of :class:`Button`'s or :class:`SelectMenu`'
         file: :class:`~discord.File`
             The file to upload.
         files: List[:class:`~discord.File`]
@@ -997,6 +1003,10 @@ class Messageable(metaclass=abc.ABCMeta):
 
             .. versionadded:: 1.6
 
+        hidden: Optional[:class:`bool`]
+            If :bool:`True` the message will be only bee visible for the performer of the interaction.
+            If this isnt called within an :class:`RawInteractionCreateEvent` it will be ignored
+
         Raises
         --------
         ~discord.HTTPException
@@ -1021,18 +1031,24 @@ class Messageable(metaclass=abc.ABCMeta):
 
         if embed is not None:
             embed = embed.to_dict()
-
+        embed_list = []
+        if embed:
+            embed_list.append(embed)
+        if embeds:
+            embed_list.extend([e.to_dict() for e in embeds])
+        embeds = embed_list
+        if len(embeds) > 10:
+            raise InvalidArgument(f'The maximum number of embeds that can be send with a message is 10, got: {len(embeds)}')
         if components:
-            components_list = []
-            for component in ([components] if not type(components) == list else components):
-                if isinstance(component, Button):
-                    components_list.append(component.to_dict())
-                elif isinstance(component, DropdownMenue):
-                    coponent_liste.append(component.to_dict())
+            _components = []
+            for component in ([components] if not isinstance(components, list) else components):
+                if isinstance(component, (Button, SelectMenu)):
+                    _components.extend(ActionRow(component).to_dict())
                 elif isinstance(component, ActionRow):
-                    components_list.extend(component.sendable())
-            components = components_list
-            
+                    _components.extend(component.to_dict())
+                elif isinstance(component, list):
+                    _components.extend(ActionRow(*[obj for obj in component if isinstance(obj, (Button, SelectMenu))]).to_dict())
+            components = _components
 
         if allowed_mentions is not None:
             if state.allowed_mentions is not None:
@@ -1055,14 +1071,38 @@ class Messageable(metaclass=abc.ABCMeta):
         if file is not None and files is not None:
             raise InvalidArgument('cannot pass both file and files parameter to send()')
 
+        is_interaction_response = kwargs.pop('__is_interaction_response', None)
+        deferred = kwargs.pop('__deferred', False)
+        use_webhook = kwargs.pop('__use_webhook', False)
+        interaction_id = kwargs.pop('__interaction_id', None)
+        interaction_token = kwargs.pop('__interaction_token', None)
+        application_id = kwargs.pop('__application_id', None)
+        followup = kwargs.pop('followup', False)
+        if is_interaction_response is False or None:
+            hidden = None
+        if hidden is True and file or files:
+            raise AttributeError('An ephemeral(hidden) Message could not contain file(s)')
         if file is not None:
             if not isinstance(file, File):
                 raise InvalidArgument('file parameter must be File')
 
             try:
-                data = await state.http.send_files(channel.id, files=[file], allowed_mentions=allowed_mentions,
-                                                   content=content, tts=tts, embed=embed, components=components,
-                                                   nonce=nonce, message_reference=reference)
+                if hidden is not None:
+                    data = await state.http.send_interaction_response(use_webhook=use_webhook,
+                                                                      interaction_id=interaction_id,
+                                                                      token=interaction_token,
+                                                                      application_id=application_id,
+                                                                      deferred=deferred,
+                                                                      files=[file], allowed_mentions=allowed_mentions,
+                                                                      content=content, tts=tts, embeds=embeds,
+                                                                      components=components,
+                                                                      nonce=nonce, message_reference=reference,
+                                                                      flags=64 if hidden is True else None,
+                                                                      followup=followup)
+                else:
+                    data = await state.http.send_files(channel.id, files=[file], allowed_mentions=allowed_mentions,
+                                                       content=content, tts=tts, embeds=embeds, components=components,
+                                                       nonce=nonce, message_reference=reference)
             finally:
                 file.close()
 
@@ -1073,21 +1113,49 @@ class Messageable(metaclass=abc.ABCMeta):
                 raise InvalidArgument('files parameter must be a list of File')
 
             try:
-                data = await state.http.send_files(channel.id, files=files, content=content, tts=tts,
-                                                   embed=embed, components=components, nonce=nonce,
-                                                   allowed_mentions=allowed_mentions, message_reference=reference)
+                if hidden is not None:
+                    data = await state.http.send_interaction_response(use_webhook=use_webhook,
+                                                                      interaction_id=interaction_id,
+                                                                      token=interaction_token,
+                                                                      application_id=application_id,
+                                                                      deferred=deferred,
+                                                                      files=file, allowed_mentions=allowed_mentions,
+                                                                      content=content, tts=tts, embeds=embeds,
+                                                                      components=components,
+                                                                      nonce=nonce, message_reference=reference,
+                                                                      flags=64 if hidden is True else None,
+                                                                      followup=followup or deferred)
+                else:
+                    data = await state.http.send_files(channel.id, files=files, content=content, tts=tts,
+                                                       embeds=embeds, components=components, nonce=nonce,
+                                                       allowed_mentions=allowed_mentions, message_reference=reference)
             finally:
                 for f in files:
                     f.close()
         else:
-            data = await state.http.send_message(channel.id, content, tts=tts, embed=embed, components=components,
-                                                                      nonce=nonce, allowed_mentions=allowed_mentions,
-                                                                      message_reference=reference)
-
-        ret = state.create_message(channel=channel, data=data)
-        if delete_after is not None:
-            await ret.delete(delay=delete_after)
-        return ret
+            if hidden is not None:
+                data = await state.http.send_interaction_response(use_webhook=use_webhook,
+                                                                  interaction_id=interaction_id,
+                                                                  token=interaction_token,
+                                                                  application_id=application_id,
+                                                                  deferred=deferred, allowed_mentions=allowed_mentions,
+                                                                  content=content, tts=tts, embeds=embeds,
+                                                                  components=components,
+                                                                  nonce=nonce, message_reference=reference,
+                                                                  flags=64 if hidden is True else None,
+                                                                  followup=followup)
+            else:
+                data = await state.http.send_message(channel.id, content, tts=tts, embeds=embeds, components=components,
+                                                                          nonce=nonce, allowed_mentions=allowed_mentions,
+                                                                          message_reference=reference)
+        if not hidden is True:
+            if not isinstance(data, dict) and not hidden is None:
+                """Thanks Discord that they dont return the message when we send the interaction callback"""
+                data = await state.http.get_original_interaction_response(application_id=application_id, interaction_token=interaction_token)
+            ret = state.create_message(channel=channel, data=data)
+            if (delete_after is not None) and (not hidden is True):
+                await ret.delete(delay=delete_after)
+            return ret
 
     async def trigger_typing(self):
         """|coro|
